@@ -7,8 +7,7 @@ from termcolor import ATTRIBUTES, colored
 from textwrap import wrap
 
 
-__all__ = ["choice", "colored", "re", "strip_escape_codes", "term_width",
-           "wrap", "Object", "ObjectTooLarge", "FONTS"]
+__all__ = ["choice", "colored", "re", "strip_escape_codes", "term_width", "wrap", "Object", "ObjectTooLarge", "FONTS"]
 
 # little patch to available attributes ; may not work for some terminals
 ATTRIBUTES['italic'] = 3
@@ -20,7 +19,7 @@ with open(join(dirname(__file__), "fonts.txt")) as f:
 
 
 strip_escape_codes = lambda s: re.sub(r"(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]", "", s)
-term_width = lambda: terminal_size()[0]
+term_width = lambda: terminal_size()[0] or 79
 
 
 class Object(object):
@@ -30,8 +29,7 @@ class Object(object):
     
     @staticmethod
     def check_width(text, width=term_width()):
-        """ Generic method for checking if the ASCII art object does not exceed
-             the configured width. """
+        """ Generic method for checking if the ASCII art object does not exceed the configured width. """
         if any(len(l) > width for l in text.splitlines()):
             raise ObjectTooLarge("Object does not fit the given width")
     
@@ -43,3 +41,4 @@ class Object(object):
 
 class ObjectTooLarge(ValueError):
     pass
+
