@@ -2,10 +2,11 @@
 """AsciiStuff package information.
 
 """
+import os
 
 __author__    = "Alexandre D'Hondt"
 __copyright__ = "© 2019 A. D'Hondt"
 __license__   = "AGPLv3 (http://www.gnu.org/licenses/agpl.html)"
 
-with open("VERSION.TXT") as f:
+with open(os.path.join(os.path.dirname(__file__), "VERSION.txt")) as f:
     __version__ = f.read().strip()
